Crate chezmoi_modify_manager

This is not a stable API, and is to be used internally by the binary and the integration tests only.

Enums

ChmmArgs
Add-on for chezmoi to handle mixed settings and state
Style
The style of calls to the executable

Functions

inner_main
Main function, amenable to integration tests.
parse_args
Apply arg parser to standard arguments