This is not a stable API, and is to be used internally by the binary and the integration tests only.
Enums
- Chmm
Args - Add-on for chezmoi to handle mixed settings and state
- Style
- The style of calls to the executable
Functions
- inner_
main - Main function, amenable to integration tests.
- parse_
args - Apply arg parser to standard arguments